import React, { useState, useEffect } from "react"
import Taro from "@tarojs/taro";
import { View, Input, Swiper, Image, SwiperItem, Text, ScrollView } from "@tarojs/components"
import positionImg from '@/assets/comm/position.png'
import searchImg from '@/assets/comm/search.png'
import orderImg from '@/assets/comm/orderList.png'
import Footer from "@/components/Footer";
import MyCard from "@/components/MyCard";
import NullCard from "@/components/NullCard";
import { getBannerList } from "@/services/banner";
import { getOrderList } from "@/services/order";
import './style.less'


export default (props) => {
  const [imgList, setImgList] = useState([])
  const [orderList, setOrderList] = useState([])
  const [currentPage,setCurrentPage]=useState(1)
  const [isMore,setIsMore]=useState(false)
  const [q,setQ]=useState()

  const handleSearch = (e) => {
    setIsMore(false)
    setCurrentPage(1)
    setQ(e.detail.value)
  }
  const handleMore = () => {
    Taro.navigateTo({ url: '/pages/moreOrder/index' });
  }
  const handleDetail = (val) => {
    Taro.navigateTo({ url: `/pages/orderDetail/index?id=${val}` });
  }
  // 上拉加载
  const handleScrollToLower=()=>{
    setCurrentPage(currentPage+1)
  }

  useEffect(()=>{
    getOrderList({pageNum:currentPage,q:q}).then(res=>{
      const lst = currentPage === 1 ? res.records || [] : orderList.concat(res.records || [])
      //长列表加载当下一页没有数据时
      if (res.records.length==0&&currentPage!=1) {
        setIsMore(true)
        return
      }
      setOrderList(lst)
    })
  },[currentPage,q])
  useEffect(() => {
    getBannerList({ position: 'bannerWorker' })
      .then(res => {
        setImgList(res)
      }).catch(err => {
        Taro.showToast({
          title: '网络异常, 请刷新小程序重试',
          icon: 'none',
        })
      })
  }, [])
  return (
    <View className='orderIndex'>
      <View className='top'>
        <View className='left'>
          <Image src={positionImg} className='pImg' />
          <Text>邓州市</Text>
          <View className='icon' />
        </View>
        <View className='searchClass'>
          <Input type='text' className='searchInput' onBlur={handleSearch} placeholder='搜索关键字查询订单' />
          <Image src={searchImg} className='searchImg' />
        </View>
      </View>
      <ScrollView
        scrollY
        enhanced
        onScrollToLower={isMore?'':handleScrollToLower}
        style={{ height: 'calc(100% - 50px)' }}
      >
        <View>
          <Swiper
            circular
            autoplay
            className='swiper'
          >
            {imgList.map((item, inx) => (
              <SwiperItem key={inx}>
                <Image src={item.thumb} mode='widthFix' className='storeImage' />
              </SwiperItem>
            ))}
          </Swiper>
        </View>
        <View className='orderList'>
          <View className='head'>
            <Image className='headIcon' src={orderImg} />
            <Text className='title'>订单列表</Text>
            <Text className='more' onClick={handleMore}>更多{">"}{">"}</Text>
          </View>
          {
            orderList.length === 0 ? <NullCard value='您还没有新的订单！' /> :
              orderList.map((item) => {
                return <MyCard order value={item} key={item.orderId} goDetail={() => handleDetail(item.orderId)} />
              })
          }
          {
            isMore&&<Footer />
          }          
        </View>
      </ScrollView>
    </View>
  )
}