import Taro from "@tarojs/taro";
import { useState, useEffect } from "react";
import { View, Input, Image, Text, ScrollView } from "@tarojs/components"
import CustomNav from "@/components/CustomNav";
import searchImg from '@/assets/comm/search.png'
import withLayout from '@/layouts'
import NullCard from "@/components/NullCard";
import MyCard from "@/components/MyCard";
import Footer from "@/components/Footer";
import { getOrderList } from "@/services/order";
import './style.less'

export default withLayout(() => {
  const [imageShow, setImageShow] = useState(true)
  const [currentTab, setCurrentTab] = useState(0);
  const [orderList, setOrderList] = useState([])
  const handleSearch = (e) => {
    if (e.detail.value) {
      console.log(e.detail.value)
      setImageShow(false)
    } else {
      setImageShow(true)
    }
    getOrderList({q:e.detail.value}).then((res) => {
      setOrderList(res.records)
    })
  }
  const handleClick = () => {
    setImageShow(false)
  }
  const handleChange = (val) => {
    setCurrentTab(val)
  }
  const handleDetail = (val) => {
    Taro.navigateTo({ url: `/pages/orderDetail/index?id=${val}` });
  }
  useEffect(() => {
    getOrderList().then((res) => {
      console.log(res.records)
      setOrderList(res.records)
    })
  }, [])
  return (
    <View className='page-index'>
      <View className='index-navbar'>
        <CustomNav title='更多' />
      </View>
      <View className='searchClass'>
        <Input type='text' className='searchInput' onClick={handleClick} onBlur={handleSearch} placeholder='搜索关键字查询订单' />
        {
          imageShow && (
            <Image src={searchImg} className='searchImg' />
          )
        }
      </View>
      <View className='tabbar'>
        <View
          className={['tabberItem', currentTab === 0 ? "activeTabber" : '']}
          onClick={() => handleChange(0)}
        >
          <View>
            <Text className='text'>待作业</Text>
            {
              currentTab === 0 && <View className='line' />
            }
          </View>
        </View>
        <View
          className={['tabberItem', currentTab === 1 ? "activeTabber" : '']}
          onClick={() => handleChange(1)}
        >
          <View>
            <Text className='text'>进行中</Text>
            {
              currentTab === 1 && <View className='line' />
            }
          </View>
        </View>
        <View
          className={['tabberItem', currentTab === 2 ? "activeTabber" : '']}
          onClick={() => handleChange(2)}
        >
          <View>
            <Text className='text'>已完成</Text>
            {
              currentTab === 2 && <View className='line' />
            }
          </View>
        </View>
      </View>
      <View className='index-container'>
        <ScrollView scrollY style={{ height: '100%' }}>
          {/* {currentTab} */}
          {
            orderList.length===0?<NullCard value='您还没有新的订单！' />:
            orderList.map((item)=>{
              return <MyCard order value={item} key={item.orderId} goDetail={()=>handleDetail(item.orderId)} />
            })
          }
          {/* <Footer /> */}
        </ScrollView>
        {/* {currentTab === 0 && <View>777</View>}
        {currentTab === 1 && <View>888</View>}
        {currentTab === 2 && <View>999</View>} */}
      </View>
    </View>
  )
})